package App::jpath;

our $VERSION = '0.04'; # VERSION

1;
# ABSTRACT: Command-line tool for JSON::Path

__END__

=pod

=encoding UTF-8

=head1 NAME

App::jpath - Command-line tool for JSON::Path

=head1 VERSION

This document describes version 0.04 of App::jpath (from Perl distribution App-jpath), released on 2016-03-11.

=head1 SYNOPSIS

See the command-line script L<jpath>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-jpath>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-jpath>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-jpath>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
